@@ -319,7 +319,7 @@ Veuillez attendre la fin du processus</translation>
     <message>
         <location filename="mainwindow.cpp" line="355"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>À propos %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="356"/>
@@ -339,12 +339,12 @@ Veuillez attendre la fin du processus</translation>
     <message>
         <location filename="mainwindow.cpp" line="360"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 Licence</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="368"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Aide</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="379"/>
