@@ -237,12 +237,12 @@
     <message>
         <location filename="mainwindow.ui" line="727"/>
         <source>Dry run (no change to system)</source>
-        <translation>Execução a seco (não altera o sistema)</translation>
+        <translation>Simulação (não altera o sistema)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="734"/>
         <source>clone from a mounted live-usb or iso-file.</source>
-        <translation>Clonar a partir de uma USB-executável ou de um ficheiro ISO montado.</translation>
+        <translation>Clonar uma USB-executável ou um ficheiro ISO montados.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="737"/>
