@@ -24,7 +24,7 @@
     <message>
         <location filename="mainwindow.ui" line="88"/>
         <source>Display help </source>
-        <translation>Exibir a ajuda</translation>
+        <translation>Exibir ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="91"/>
@@ -39,7 +39,7 @@
     <message>
         <location filename="mainwindow.ui" line="114"/>
         <source>Back</source>
-        <translation>Anterior</translation>
+        <translation>Voltar</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="172"/>
@@ -49,7 +49,7 @@
     <message>
         <location filename="mainwindow.ui" line="198"/>
         <source>About this application</source>
-        <translation>Sobre esta aplicação</translation>
+        <translation>Sobre este aplicativo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="201"/>
@@ -66,17 +66,17 @@
         <location filename="mainwindow.cpp" line="462"/>
         <location filename="mainwindow.cpp" line="481"/>
         <source>Select ISO</source>
-        <translation>Seleccionar ficheiro ISO</translation>
+        <translation>Selecione o arquivo ISO</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="250"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecionar Dispositivo USB a usar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o Dispositivo USB  de Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="260"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccionar ficheiro ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o arquivo ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="289"/>
@@ -86,17 +86,17 @@
     <message>
         <location filename="mainwindow.ui" line="307"/>
         <source>Make the ext4 filesystem even if one exists</source>
-        <translation>Formatar em ext4 mesmo que já esteja formatado nesse sistema</translation>
+        <translation>Formate em ext4 mesmo que já esteja formatado nesse sistema de arquivos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="314"/>
         <source>Save the original boot directory when updating a live-usb</source>
-        <translation>Guardar o directório original boot ao actualizar uma penUSB-executável</translation>
+        <translation>Salve o diretório original de inicialização (boot) ao atualizar o USB Executável</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="321"/>
         <source>Use gpt partitioning instead of msdos</source>
-        <translation>Usar particionamento gpt em vez de msdos</translation>
+        <translation>Use o particionamento gpt em vez de msdos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="324"/>
@@ -106,17 +106,17 @@
     <message>
         <location filename="mainwindow.ui" line="331"/>
         <source>Update (only update an existing live-usb)</source>
-        <translation>Actualizar (apenas penUSB-executável existente)</translation>
+        <translation>Atualizar (apenas o USB Executável existente)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
         <source>Don&apos;t replace syslinux files</source>
-        <translation>Não substituir os ficheiros syslinux</translation>
+        <translation>Não substitua os arquivos syslinux</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="341"/>
         <source>Keep syslinux files</source>
-        <translation>Manter os ficheiros syslinux</translation>
+        <translation>Manter os arquivos syslinux</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="348"/>
@@ -126,17 +126,17 @@
     <message>
         <location filename="mainwindow.ui" line="355"/>
         <source>Temporarily disable automounting</source>
-        <translation>Desactivar temporariamente a montagem automática</translation>
+        <translation>Desativar temporariamente a montagem automática</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="365"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
-        <translation>Atribuir a &apos;flag&apos; de disco &apos;pmbr_boot&apos; (não iniciará via UEFI)</translation>
+        <translation>Definir o marcador (flag) de disco &apos;pmbr_boot&apos; (não inicializa via UEFI)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
-        <translation>Não usar fuseiso para montar ficheiros iso</translation>
+        <translation>Não use o fuseiso para montar arquivos ISO</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="398"/>
@@ -146,7 +146,7 @@
     <message>
         <location filename="mainwindow.ui" line="418"/>
         <source>Verbosity (less to more):</source>
-        <translation>Nível de detalhe (de menos para mais):</translation>
+        <translation>Nível de detalhe (do menor para o maior):</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="457"/>
@@ -171,7 +171,7 @@
     <message>
         <location filename="mainwindow.ui" line="493"/>
         <source>Make separate data partition (percent)</source>
-        <translation>Criar partição de dados separada (percentagem)</translation>
+        <translation>Crie a partição de dados separada (percentagem)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="500"/>
@@ -181,7 +181,7 @@
     <message>
         <location filename="mainwindow.ui" line="510"/>
         <source>Refresh drive list</source>
-        <translation>Actualizar a lista de dispositivos</translation>
+        <translation>Atualizar a lista de dispositivos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="524"/>
@@ -197,12 +197,12 @@
     <message>
         <location filename="mainwindow.ui" line="559"/>
         <source>Full-featured mode - writable LiveUSB</source>
-        <translation>Modo completo - LiveUSB</translation>
+        <translation>Modo completo - LiveUSB gravável</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="569"/>
         <source>Read-only, cannot be used with persistency</source>
-        <translation>Só de leitura; não pode ser usado com &apos;persistência&apos;</translation>
+        <translation>Somente leitura, não pode ser usado com &apos;persistência&apos;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="572"/>
@@ -212,7 +212,7 @@
     <message>
         <location filename="mainwindow.ui" line="586"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation>Para distros que não o antiX / MX use o modo de imagem (dd).</translation>
+        <translation>Para distribuições (distros) que não sejam antiX / MX, use o modo de imagem (dd).</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="634"/>
@@ -222,7 +222,7 @@
     <message>
         <location filename="mainwindow.ui" line="669"/>
         <source>Percent of USB-device to use:</source>
-        <translation>Percentagem do dispositivo USB a usar:</translation>
+        <translation>Percentagem do dispositivo USB a ser usado:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="676"/>
@@ -232,7 +232,7 @@
     <message>
         <location filename="mainwindow.ui" line="724"/>
         <source>Don&apos;t run commands that affect the usb device</source>
-        <translation>Não executar commandos que afectem o dispositivo USB</translation>
+        <translation>Não execute comandos que afetem o dispositivo USB</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="727"/>
@@ -242,7 +242,7 @@
     <message>
         <location filename="mainwindow.ui" line="734"/>
         <source>clone from a mounted live-usb or iso-file.</source>
-        <translation>clonar a partir de USB-executável ou ficheiro ISO montado.</translation>
+        <translation>clonar a partir de USB Executável ou arquivo ISO montado.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="737"/>
@@ -252,12 +252,12 @@
     <message>
         <location filename="mainwindow.ui" line="744"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation>Definir para arrancar de partição encriptada; pedirá uma frase-senha no primeiro arranque</translation>
+        <translation>Configurar para inicializar a partir de uma partição criptografada, solicitará a frase secreta/senha na primeira inicialização</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="747"/>
         <source>Encrypt</source>
-        <translation>Encriptar</translation>
+        <translation>Criptografar/Encriptar</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="754"/>
@@ -274,31 +274,31 @@
     <message>
         <location filename="mainwindow.cpp" line="86"/>
         <source>Source and destination are on the same device, please select again.</source>
-        <translation>Origem e destino no mesmo dispositivo; seleccionar de novo.</translation>
+        <translation>A origem e o destino estão no mesmo dispositivo, selecionar novamente.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="111"/>
         <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation>A gravar %1 em /dev/%2, usando o comando &apos;dd&apos;.
+        <translation>Gravando %1, usando o comando &apos;dd&apos; em /dev/%2.
 
-Aguardar até o processo terminar</translation>
+Por favor, espere até que o processo seja concluído</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>Success</source>
-        <translation>Êxito</translation>
+        <translation>Successo</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>LiveUSB creation successful!</source>
-        <translation>Instalação externa USB criada com êxito!</translation>
+        <translation>Instalação externa USB criada com sucesso!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="267"/>
         <source>Error encountered in the LiveUSB creation process</source>
-        <translation>Erro no processo de criar a Instalação externa USB-executável</translation>
+        <translation>Erro no processo de criação da instalação externa USB Executável</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="316"/>
@@ -308,7 +308,7 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="mainwindow.cpp" line="316"/>
         <source>Please select a USB device to write to</source>
-        <translation>Seleccionar o dispositivo USB a usar</translation>
+        <translation>Por favor, selecione um dispositivo USB para ser utilizado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="319"/>
@@ -329,7 +329,7 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="mainwindow.cpp" line="357"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
-        <translation>Programa para criar instalações externas USB-executável a partir de ficheiros ISO, de outra instalação externa USB-executável, de CD/DVD-executável ou de um sistema em execução.</translation>
+        <translation>Programa para criar instalações externas USB Executável a partir de arquivos ISO, de outra instalação externa USB Executável, de CD/DVD Executável ou de um sistema em execução.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="359"/>
@@ -349,18 +349,18 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="mainwindow.cpp" line="379"/>
         <source>Select an ISO file to write to the USB drive</source>
-        <translation>Seleccionar um ficheiro ISO a instalar no disco USB</translation>
+        <translation>Selecione um arquivo ISO para instalar no dispositivo USB</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="387"/>
         <location filename="mainwindow.cpp" line="458"/>
         <source>Select Source Directory</source>
-        <translation>Seleccionar Directório Origem</translation>
+        <translation>Selecione o Diretório de Origem</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="392"/>
         <source>Could not find %1/antiX/linuxfs file</source>
-        <translation>Ficheiro %1/antiX/linuxfs não encontrado</translation>
+        <translation>Não foi possível encontrar o arquivo %1/antiX/linuxfs</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="413"/>
@@ -371,13 +371,13 @@ Aguardar até o processo terminar</translation>
         <location filename="mainwindow.cpp" line="457"/>
         <location filename="mainwindow.cpp" line="473"/>
         <source>Select Source</source>
-        <translation>Seleccionar Origem</translation>
+        <translation>Selecione a Origem</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="461"/>
         <location filename="mainwindow.cpp" line="479"/>
         <source>Select ISO file</source>
-        <translation>Seleccionar ficheiro ISO</translation>
+        <translation>Selecione o arquivo ISO</translation>
     </message>
 </context>
 <context>
@@ -406,7 +406,7 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="main.cpp" line="75"/>
         <source>You must run this program as root.</source>
-        <translation>Tem que executar este programa como administrador (root).</translation>
+        <translation>Você tem que executar este programa como administrador (root).</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
